from interface.vm.instance import InstanceInterface


class OSVirtualMachineManager(InstanceInterface):

    def __init__(self, cloud):
        super().__init__()
        self.openstack = cloud

    def create_vm_from_template(self, name, resource, template):
        flavor = self.openstack.compute.find_flavor('cirros256')
        # TODO plan flavors
        if flavor is None:
            flavor = self.openstack.compute.create_flavor(name=name, ram=resource['ram'], vcpus=resource['cpu'], disk=20)

        image = self.openstack.compute.find_image(template)
        if not image:
            raise ValueError("The template not found")

        new_server = self.openstack.compute.create_server(name=name,
                                                          flavorRef=flavor.id,
                                                          imageRef=image.id)

        new_server = self.openstack.compute.wait_for_server(new_server)

        return new_server

    def get_vm(self, name_or_id=None):
        if not name_or_id:
            raise ValueError("Name or id doesn't given")
        server_instance = self.openstack.get_server(name_or_id)
        if not server_instance:
            raise ValueError("Could not get the vm")
        return server_instance

    def start_vm(self, name_or_id=None):
        if name_or_id:
            instance = self.get_vm(name_or_id)
        self.openstack.compute.start_server(instance)

    def stop_vm(self, name_or_id=None):
        if name_or_id:
            instance = self.get_vm(name_or_id)
        self.openstack.compute.stop_server(instance)
